@@ -3,6 +3,7 @@ package net.bakingpowder.mDNSrelay.Server;
 import java.net.DatagramPacket;
 //import java.net.InetAddress;
 //import java.net.InetAddress;
+import java.net.InetAddress;
 import java.net.MulticastSocket;
 import java.net.Socket;
 import java.net.UnknownHostException;
@@ -12,16 +13,22 @@ import java.io.OutputStream;
 
 public class CollectAndSend2Client implements Runnable {
 	private Socket srcSocket, destSocket;
+
 	private OutputStream srcOut;
+
 	private InputStream srcIn;
+
 	final static int BUFFER_SIZE = 4096;
+
 	MulticastSocket ms = null;
+
 	byte[] buffer = new byte[BUFFER_SIZE];
 
-	java.util.Stack st;
-	public CollectAndSend2Client(MulticastSocket ms, Socket ss,java.util.Stack st) {
+	//java.util.Stack st;
+
+	public CollectAndSend2Client(MulticastSocket ms, Socket ss) {
 		srcSocket = ss;
-		this.st = st;
+		//this.st = st;
 		try {
 			this.ms = ms;
 			srcOut = ss.getOutputStream();
@@ -40,17 +47,16 @@ public class CollectAndSend2Client implements Runnable {
 				DatagramPacket dp = new DatagramPacket(buffer, buffer.length);
 				ms.receive(dp);
 				int gttl = ms.getTimeToLive();
-				
-					if(!st.contains(buffer)){
-					if ((gttl == 1)) {srcOut.write(buffer);}
-					} 
-					st.remove(buffer);
-					
-					if(st.size()==100){
-						st.clear();
+
+				if (dp.getAddress().equals(InetAddress.getLocalHost())) {
+					//ignore
+				} else {
+
+					if ((gttl == 1)) {
+						srcOut.write(buffer);
 					}
-					
-					//System.out.println(st.size());
+				}
+
 			} catch (IOException e) {
 				return;
 			}
